//
//  CSVData.m
//  AsReaderLR
//
//  Created by mac on 2017/8/7.
//  Copyright © 2017年 asterisk. All rights reserved.
//

#import "CSVData.h"
@implementation CSVData
+ (NSString *) filePath:(NSString *)fileName{
    
    NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
    NSString *path = [paths objectAtIndex:0];
    NSString *filePath = [path stringByAppendingPathComponent:fileName];
    return filePath;
}

+ (BOOL) isFileExist:(NSString *)fileName {
    
    NSFileManager *fileManager = [NSFileManager defaultManager];
    BOOL result = [fileManager fileExistsAtPath:[self filePath:fileName]];
    return result;
}

+ (void) deleteFileForFileName:(NSString *)fileName {
    
    NSFileManager *fileManager = [NSFileManager defaultManager];
    [fileManager removeItemAtPath:[self filePath:fileName] error:nil];
}

+ (void) createCSVWithFileName:(NSString *)fileName {
    
    NSFileManager *fileManager = [NSFileManager defaultManager];
    if (![fileManager createFileAtPath:[self filePath:fileName]  contents:nil attributes:nil]) {
    }
};

+ (void) exportRfidCSV:(NSString *)fileName withArray:(NSMutableArray *)array isEpc:(BOOL)isEpc {
    NSOutputStream *output = [[NSOutputStream alloc] initToFileAtPath:[self filePath:fileName] append:YES];
    [output open];
    
    if (![output hasSpaceAvailable]) {
        UIAlertView *alert = [[UIAlertView alloc]initWithTitle:nil message:@"" delegate:nil cancelButtonTitle:nil otherButtonTitles:@"OK", nil];
        [alert setMessage:@"Output Error"];
        [alert show];
        return;
    } else {
        NSString *header;
        if (isEpc) {
            header = @"pcepc hex,time,count\n";
        }else{
            header = @"epc hex,time,count\n";
        }
        

        const uint8_t *headerString = (const uint8_t *)[header cStringUsingEncoding:NSUTF8StringEncoding];
        NSInteger headerLength = [header lengthOfBytesUsingEncoding:NSUTF8StringEncoding];
        NSInteger result = [output write:headerString maxLength:headerLength];
        if (result <= 0) {
            UIAlertView *alert = [[UIAlertView alloc]initWithTitle:nil message:@"" delegate:nil cancelButtonTitle:nil otherButtonTitles:@"OK", nil];
            [alert setMessage:@"Output Error"];
            [alert show];
            return;
        }
        
        for (NSDictionary *dic in array) {
            NSString *row;
            if (isEpc) {
                row = [NSString stringWithFormat:@"%@,%@,%@\n", [dic objectForKey:@"tag"], [dic objectForKey:@"date"], [dic objectForKey:@"everyCodeNumber"]];
            }else{
                row = [NSString stringWithFormat:@"%@,%@,%@\n", [[dic objectForKey:@"tag"] substringFromIndex:4], [dic objectForKey:@"date"], [dic objectForKey:@"everyCodeNumber"]];
            }
            const uint8_t *rowString = (const uint8_t *)[row cStringUsingEncoding:NSUTF8StringEncoding];
            NSInteger rowLength = [row lengthOfBytesUsingEncoding:NSUTF8StringEncoding];
            result = [output write:rowString maxLength:rowLength];
            if (result <= 0) {
                UIAlertView *alert = [[UIAlertView alloc]initWithTitle:nil message:@"" delegate:nil cancelButtonTitle:nil otherButtonTitles:@"OK", nil];
                [alert setMessage:@"RFID File Output Error"];
                [alert show];
                return;
            }
        }

        UIAlertView *alert = [[UIAlertView alloc]initWithTitle:nil message:@"" delegate:nil cancelButtonTitle:nil otherButtonTitles:@"OK", nil];
        [alert setMessage:@"RFID File Output Success"];
        [alert show];
        
        [output close];
    }
}


+ (void) exportBarCodeCSV:(NSString *)fileName withArray:(NSMutableArray *)array {
    NSOutputStream *output = [[NSOutputStream alloc] initToFileAtPath:[self filePath:fileName] append:YES];
    [output open];
    
    if (![output hasSpaceAvailable]) {
        UIAlertView *alert = [[UIAlertView alloc]initWithTitle:nil message:@"" delegate:nil cancelButtonTitle:nil otherButtonTitles:@"OK", nil];
        [alert setMessage:@"Output Error"];
        [alert show];
        return;
    } else {
        NSString *header;
        
        header = @"barcode,time\n";
        
        const uint8_t *headerString = (const uint8_t *)[header cStringUsingEncoding:NSUTF8StringEncoding];
        NSInteger headerLength = [header lengthOfBytesUsingEncoding:NSUTF8StringEncoding];
        NSInteger result = [output write:headerString maxLength:headerLength];
        if (result <= 0) {
            UIAlertView *alert = [[UIAlertView alloc]initWithTitle:nil message:@"" delegate:nil cancelButtonTitle:nil otherButtonTitles:@"OK", nil];
            [alert setMessage:@"Output Error"];
            [alert show];
            return;
        }
        
        for (NSDictionary *dic in array) {
            if ([fileName isEqualToString:@"barcode.csv"]) {
                NSString *row = [NSString stringWithFormat:@"%@,%@\n", [dic objectForKey:@"barcode"], [dic objectForKey:@"date"]];
                const uint8_t *rowString = (const uint8_t *)[row cStringUsingEncoding:NSUTF8StringEncoding];
                NSInteger rowLength = [row lengthOfBytesUsingEncoding:NSUTF8StringEncoding];
                result = [output write:rowString maxLength:rowLength];
                if (result <= 0) {
                    UIAlertView *alert = [[UIAlertView alloc]initWithTitle:nil message:@"" delegate:nil cancelButtonTitle:nil otherButtonTitles:@"OK", nil];
                    [alert setMessage:@"Barcode File Output Error"];
                    [alert show];
                    return;
                }
            }
        }
  
        UIAlertView *alert = [[UIAlertView alloc]initWithTitle:nil message:@"" delegate:nil cancelButtonTitle:nil otherButtonTitles:@"OK", nil];
        [alert setMessage:@"Barcode File Output Success"];
        [alert show];
        
        [output close];
    }
}

@end
